==> thunderbird_78.7.0.orig.tar.xz: thunderbird-78.7.0/security/manager/ssl/tests/unit/test_sss_readstate_huge.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
"use strict";

// The purpose of this test is to create a site security service state file
// that is too large and see that the site security service reads it properly
// (this means discarding all entries after the 1024th).

var gSSService = null;

function checkStateRead(aSubject, aTopic, aData) {
  if (aData == PRELOAD_STATE_FILE_NAME) {
    return;
  }

  equal(aData, SSS_STATE_FILE_NAME);

  ok(
    gSSService.isSecureURI(
      Ci.nsISiteSecurityService.HEADER_HSTS,
      Services.io.newURI("https://example0.example.com"),
      0
    )
  );
  ok(
    gSSService.isSecureURI(
      Ci.nsISiteSecurityService.HEADER_HSTS,
      Services.io.newURI("https://example423.example.com"),
      0
    )
  );
  ok(
    gSSService.isSecureURI(
      Ci.nsISiteSecurityService.HEADER_HSTS,
      Services.io.newURI("https://example1023.example.com"),
      0
    )
  );
  ok(
    !gSSService.isSecureURI(
      Ci.nsISiteSecurityService.HEADER_HSTS,
      Services.io.newURI("https://example1024.example.com"),
      0
    )
  );
  ok(
    !gSSService.isSecureURI(
      Ci.nsISiteSecurityService.HEADER_HSTS,
      Services.io.newURI("https://example1025.example.com"),
      0
    )
  );
  ok(
    !gSSService.isSecureURI(
      Ci.nsISiteSecurityService.HEADER_HSTS,
      Services.io.newURI("https://example9000.example.com"),
      0
    )
  );
  ok(
    !gSSService.isSecureURI(
      Ci.nsISiteSecurityService.HEADER_HSTS,
      Services.io.newURI("https://example99999.example.com"),
      0
    )
  );
  do_test_finished();
}

function run_test() {
  let profileDir = do_get_profile();
  let stateFile = profileDir.clone();
  stateFile.append(SSS_STATE_FILE_NAME);
  // Assuming we're working with a clean slate, the file shouldn't exist
  // until we create it.
  ok(!stateFile.exists());
  let outputStream = FileUtils.openFileOutputStream(stateFile);
  let expiryTime = Date.now() + 100000;
  let lines = [];
  for (let i = 0; i < 10000; i++) {
    // The 0s will all get squashed down into one 0 when they are read.
    // This is just to make the file size large (>2MB).
    lines.push(
      `example${i}.example.com:HSTS\t` +
        "0000000000000000000000000000000000000000000000000\t" +
        "00000000000000000000000000000000000000\t" +
        `${expiryTime},1,0000000000000000000000000000000000000000000000000000000000000000000000000`
    );
  }
  writeLinesAndClose(lines, outputStream);
  Services.obs.addObserver(checkStateRead, "data-storage-ready");
  do_test_pending();
  gSSService = Cc["@mozilla.org/ssservice;1"].getService(
    Ci.nsISiteSecurityService
  );
  notEqual(gSSService, null);
}

==> thunderbird_91.12.0.orig.tar.xz: thunderbird-91.12.0/security/manager/ssl/tests/unit/test_sss_readstate_huge.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
"use strict";

// The purpose of this test is to create a site security service state file
// that is too large and see that the site security service reads it properly
// (this means discarding all entries after the 1024th).

var gSSService = null;

function checkStateRead(aSubject, aTopic, aData) {
  if (aData == CLIENT_AUTH_FILE_NAME) {
    return;
  }

  equal(aData, SSS_STATE_FILE_NAME);

  ok(
    gSSService.isSecureURI(
      Services.io.newURI("https://example0.example.com"),
      0
    )
  );
  ok(
    gSSService.isSecureURI(
      Services.io.newURI("https://example423.example.com"),
      0
    )
  );
  ok(
    gSSService.isSecureURI(
      Services.io.newURI("https://example1023.example.com"),
      0
    )
  );
  ok(
    !gSSService.isSecureURI(
      Services.io.newURI("https://example1024.example.com"),
      0
    )
  );
  ok(
    !gSSService.isSecureURI(
      Services.io.newURI("https://example1025.example.com"),
      0
    )
  );
  ok(
    !gSSService.isSecureURI(
      Services.io.newURI("https://example9000.example.com"),
      0
    )
  );
  ok(
    !gSSService.isSecureURI(
      Services.io.newURI("https://example99999.example.com"),
      0
    )
  );
  do_test_finished();
}

function run_test() {
  let profileDir = do_get_profile();
  let stateFile = profileDir.clone();
  stateFile.append(SSS_STATE_FILE_NAME);
  // Assuming we're working with a clean slate, the file shouldn't exist
  // until we create it.
  ok(!stateFile.exists());
  let outputStream = FileUtils.openFileOutputStream(stateFile);
  let expiryTime = Date.now() + 100000;
  let lines = [];
  for (let i = 0; i < 10000; i++) {
    // The 0s will all get squashed down into one 0 when they are read.
    // This is just to make the file size large (>2MB).
    lines.push(
      `example${i}.example.com:HSTS\t` +
        "0000000000000000000000000000000000000000000000000\t" +
        "00000000000000000000000000000000000000\t" +
        `${expiryTime},1,0000000000000000000000000000000000000000000000000000000000000000000000000`
    );
  }
  writeLinesAndClose(lines, outputStream);
  Services.obs.addObserver(checkStateRead, "data-storage-ready");
  do_test_pending();
  gSSService = Cc["@mozilla.org/ssservice;1"].getService(
    Ci.nsISiteSecurityService
  );
  notEqual(gSSService, null);
}
